# Converter

Converter is a subcomponent of the ACCORDION platform. It is being used by the Orchestrator and Lifecycle Manager components in order to translate the application model to K3s configuration files, action models, workflow models and matchmaking models

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip3 install converter-package==0.9
```

## Usage
Interface.py is an example of usage, it is available on the ACCORDION's Gitlab


## License
[MIT](https://choosealicense.com/licenses/mit/)